@@ -27,8 +27,6 @@ from .modelnet40.model_pointnet_plus import (pointnet_plus_modelnet40,
                                              pointnet_plus_modelnet40_pretrained
                                              )
 from .utk_face.model_vgg import vgg_utk_face, vgg_utk_face_pretrained
-from .cse2018.model_tse import tse_mlp_cse2018, tse_mlp_cse2018_pretrained
-from .tabular_data import tabular_data
 from .detection.model_yolo import (yolo_base, yolo_widerface_pretrained,
                                    yolo_voc_pretrained)
 from .cwru.model_convtiny import convtiny_cwru, convtiny_cwru_pretrained
@@ -41,6 +39,7 @@ from .transformers.model_deit import (
     bc_deit_dist_ti16_imagenet_pretrained, deit_s16, deit_b16)
 from .portrait128.model_akida_unet import akida_unet_portrait128
 
+from .calibrable import calibration_required
 from .gamma_constraint import add_gamma_constraint
 from .filter_pruning import delete_filters, prune_model
 from .renaming import rename_model_layers
