@@ -1,5 +1,5 @@
-# ******************************************************************************
 #!/usr/bin/env python
+# ******************************************************************************
 # Copyright 2020 Brainchip Holdings Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,6 +20,7 @@ Training script for YOLO models.
 
 import pickle
 import argparse
+import numpy as np
 
 from keras import Model
 from keras.layers import Reshape
@@ -142,6 +143,28 @@ def evaluate(model, valid_data, anchors, labels, obj_threshold, nms_threshold):
     print('mAP: {:.4f}'.format(mAP))
 
 
+def extract_samples(im_size, data, grid_size, anchors, labels, num_samples, out_file):
+    """ Extract samples from data and save them to a .npz file.
+
+    Args:
+        im_size (int): image size
+        data (dict): data container
+        grid_size (tuple): the grid size
+        anchors (list): list of anchors
+        labels (list): list of labels
+        num_samples (int): number of samples to extract
+        out_file (str): name of output file
+    """
+    data_generator = BatchGenerator(input_shape=im_size,
+                                    data=data,
+                                    grid_size=grid_size,
+                                    labels=labels,
+                                    anchors=anchors,
+                                    batch_size=num_samples)
+    np.savez(out_file, data_generator[0][0])
+    print(f"Samples saved as {out_file}")
+
+
 def main():
     """ Entry point for script and CLI usage.
     """
@@ -167,11 +190,18 @@ def main():
                                default=0.5,
                                help="Non-Maximal Suppression threshold.")
 
-    parser = get_training_parser(batch_size=128,
-                                 freeze_before=True,
-                                 tune=True,
-                                 global_parser=global_parser)[0]
-    args = parser.parse_args()
+    parsers = get_training_parser(batch_size=128,
+                                  freeze_before=True,
+                                  tune=True,
+                                  global_parser=global_parser)
+    subparser = parsers[-1]
+    extract_parser = subparser.add_parser("extract",
+                                          help="Extract samples",
+                                          parents=[global_parser])
+    extract_parser.add_argument("-o", "--out_file", type=str,
+                                default='widerface_samples.npz', help="Name of the output file.")
+
+    args = parsers[0].parse_args()
 
     # Load data
     train_data, valid_data, labels, anchors = get_data(args.data,
@@ -225,6 +255,11 @@ def main():
         evaluate(model, valid_data, anchors, labels, args.obj_thresh,
                  args.nms_thresh)
 
+    elif args.action == 'extract':
+        input_shape = model.input.shape[1:]
+        extract_samples(input_shape, train_data, grid_size, anchors,
+                        labels, args.batch_size, args.out_file)
+
 
 if __name__ == "__main__":
     main()
