@@ -53,6 +53,10 @@ class Distiller(Model):
     def base_model(self):
         return self.student
 
+    @property
+    def layers(self):
+        return self.base_model.layers
+
     def compile(self,
                 optimizer,
                 metrics,
@@ -225,21 +229,20 @@ class DeitDistiller(Distiller):
             student_loss_fn = partial(_loss_forward, loss_fn=student_loss_fn)
             super().compile(optimizer, metrics, student_loss_fn, distillation_loss_fn)
 
+    def _update_metrics(self, metrics):
+        # Rename keys in the result dictionary for a more explicit display
+        return {k.replace('output_1_', 'head_').replace('output_2_', 'dist_head_')
+                 .replace('output_3_', ''): v for k, v in metrics.items()}
+
     def train_step(self, data):
         if self.teacher is None:
             return self.student.train_step(data)
-        # Rename output_3_XX keys to XX in the result dictionary for a nicer display,
-        # and leave this metric as the main one.
-        results = {k.replace('output_3_', ''): v for k, v in super().train_step(data).items()}
-        return results
+        return self._update_metrics(super().train_step(data))
 
     def test_step(self, data):
         if self.teacher is None:
             return self.student.test_step(data)
-        # Rename output_3_XX keys to XX in the result dictionary for a nicer display,
-        # and leave this metric as the main one.
-        results = {k.replace('output_3_', ''): v for k, v in super().test_step(data).items()}
-        return results
+        return self._update_metrics(super().test_step(data))
 
 
 class KLDistillationLoss(KLDivergence):
