@@ -25,7 +25,10 @@ import argparse
 
 import numpy as np
 import tensorflow as tf
-import tensorflow_datasets as tfds
+try:
+    import tensorflow_datasets as tfds
+except ImportError:
+    tfds = None
 
 import keras
 from keras.callbacks import TensorBoard, ModelCheckpoint, LearningRateScheduler
@@ -41,8 +44,9 @@ from quantizeml.layers import AddPositionEmbs, ClassToken
 from quantizeml.models import load_model
 
 from .preprocessing import preprocess_image, DATA_AUGMENTATION
-from ..training import (get_training_parser, freeze_model_before, print_history_stats,
-                        EarlyStoppingCalibration)
+from ..training import (get_training_parser, calibrate_model, freeze_model_before,
+                        print_history_stats)
+from ..calibrable import calibration_required
 from ..transformers.model_vit import apply_embedding_weights
 from ..distiller import DeitDistiller
 
@@ -81,6 +85,8 @@ def get_imagenet_dataset(data_path, training, image_size, batch_size, data_aug=T
         tf.dataset, int: the requested dataset (train or validation) and the
         corresponding steps
     """
+    assert tfds is not None, "To load imagenet dataset, tensorflow-datasets module must\
+        be installed."
     # Build the dataset
     write_dir = os.path.join(data_path, 'tfds')
 
@@ -360,11 +366,16 @@ def train(model,
         lrs_cos (bool, optional): True to use cosine learning rate scheduler instead of the default
           exponential rule. Defaults to False.
     """
-    # 1. Define training callbacks
+    # 1. Check model validity
+    if calibration_required(model):
+        str_action = "tune" if tune else "train"
+        raise ValueError(f"{model.name} model must be calibrated before a {str_action}.")
+
+    # 2. Define training callbacks
     callbacks = []
 
     if lrs_cos:
-        # 1.1 Learning rate scheduler, modified by tune procedure
+        # 2.1 Learning rate scheduler, modified by tune procedure
         LR_START = learning_rate
         if tune:
             LR_EPOCH_CONSTANT = 2  # number of epochs you first keep the learning rate constant
@@ -392,7 +403,7 @@ def train(model,
 
         callbacks.append(LearningRateScheduler(cos_lr_scheduler))
     else:
-        # 1.1 Learning rate scheduler
+        # 2.1 Learning rate scheduler
         LR_START = learning_rate
         LR_END = 1e-4
         # number of epochs you first keep the learning rate constant
@@ -417,10 +428,9 @@ def train(model,
 
         callbacks.append(LearningRateScheduler(agg_lr_scheduler))
 
-    # 1.2 Model checkpoints (save best models after each epoch)
+    # 2.2 Model checkpoints (save best models after each epoch)
     log_dir = create_log_dir(out_dir)
-    filepath = os.path.join(
-        log_dir, 'weights_epoch_{epoch:02d}_val_acc_{val_accuracy:.2f}.h5')
+    filepath = os.path.join(log_dir, 'best_weights.h5')
     model_checkpoint = ModelCheckpoint(filepath=filepath,
                                        monitor='val_accuracy',
                                        verbose=1,
@@ -428,7 +438,7 @@ def train(model,
                                        mode='max')
     callbacks.append(model_checkpoint)
 
-    # 1.3 Tensorboard logs
+    # 2.3 Tensorboard logs
     file_writer = tf.summary.create_file_writer(log_dir + "/metrics")
     file_writer.set_as_default()
     tensorboard = TensorBoard(log_dir=log_dir,
@@ -438,11 +448,7 @@ def train(model,
                               profile_batch=0)
     callbacks.append(tensorboard)
 
-    # 1.4 Custom callbacks
-    # Callback to calibrate the model only on the first epoch
-    callbacks.append(EarlyStoppingCalibration(trigger_epoch=1))
-
-    # 2. Train
+    # 3. Train
     history = model.fit(train_dataset,
                         steps_per_epoch=train_steps,
                         epochs=num_epochs,
@@ -452,6 +458,10 @@ def train(model,
                         initial_epoch=initial_epoch)
     print_history_stats(history)
 
+    # 4. Restore best weights
+    if os.path.exists(filepath):
+        model.load_weights(filepath)
+
 
 def main():
     """ Entry point for script and CLI usage.
@@ -470,6 +480,7 @@ def main():
                                help="The output directory (logs, checkpoints).")
 
     parsers = get_training_parser(batch_size=128,
+                                  calibrate=True,
                                   freeze_before=True,
                                   tune=True,
                                   global_parser=global_parser)
@@ -631,6 +642,19 @@ def main():
             m.save(args.savemodel, include_optimizer=False)
             print(f"Rescaled model saved as {args.savemodel}")
 
+    elif args.action == "calibrate":
+        # Calibrate model
+        # Load training data without data augmentation
+        train_ds, train_steps = get_imagenet_dataset(args.data_dir, True,
+                                                     im_size, args.batch_size,
+                                                     False, one_hot=one_hot)
+        calibrate_model(model, train_ds, args.num_samples, args.batch_size, args.epochs)
+
+        # Save model in Keras format (h5)
+        if args.savemodel:
+            model.save(args.savemodel, include_optimizer=False)
+            print(f"Calibrated model saved as {args.savemodel}")
+
 
 if __name__ == "__main__":
     main()
