@@ -16,7 +16,8 @@
 Model definitions for simple speech recognition.
 
 Brainchip information:
-        - Original file: https://github.com/tensorflow/tensorflow/tree/master/tensorflow/examples/speech_commands
+    - Original file:
+      https://github.com/tensorflow/tensorflow/tree/master/tensorflow/examples/speech_commands
 """
 
 import hashlib
@@ -32,7 +33,7 @@ import urllib
 import numpy as np
 import tensorflow as tf
 
-from tensorflow.python.ops import gen_audio_ops as audio_ops  # pylint: disable=no-name-in-module
+from tensorflow.python.ops import gen_audio_ops as audio_ops
 
 MAX_NUM_WAVS_PER_CLASS = 2**27 - 1  # ~134M
 SILENCE_LABEL = '_silence_'
@@ -371,10 +372,6 @@ class AudioProcessor():
             scaled_foreground = tf.multiply(wav_decoder.audio,
                                             foreground_volume)
             # Shift the sample's start position, and pad any gaps with zeros.
-            # pylint must be disabled here as it incorrectly identifies tf API
-            # as explained in
-            # https://github.com/tensorflow/tensorflow/issues/43038.
-            # pylint: disable=no-value-for-parameter
             padded_foreground = tf.pad(scaled_foreground, time_shift_padding)
             sliced_foreground = tf.slice(padded_foreground, time_shift_offset,
                                          [desired_samples, -1])
@@ -479,7 +476,7 @@ class AudioProcessor():
                 background_index = np.random.randint(len(self.background_data))
                 background_samples = self.background_data[background_index]
                 if len(background_samples
-                      ) <= self.model_settings['desired_samples']:
+                       ) <= self.model_settings['desired_samples']:
                     raise ValueError(
                         'Background sample is too short! Need more than %d'
                         ' samples but only %d were found' %
@@ -604,7 +601,7 @@ class AudioProcessor():
                 background_index = np.random.randint(len(self.background_data))
                 background_samples = self.background_data[background_index]
                 if len(background_samples
-                      ) <= self.model_settings['desired_samples']:
+                       ) <= self.model_settings['desired_samples']:
                     raise ValueError(
                         'Background sample is too short! Need more than %d'
                         ' samples but only %d were found' %
