@@ -24,8 +24,7 @@ import numpy as np
 from keras.preprocessing.image import DirectoryIterator
 from keras.optimizers import Adam
 from keras.layers import Activation
-from keras.callbacks import Callback
-
+from keras.utils.generic_utils import Progbar
 from quantizeml.models import set_calibrate
 
 
@@ -72,6 +71,31 @@ def freeze_model_before(model, freeze_before):
             raise ValueError(f"No such layer {freeze_before} in model.")
 
 
+def calibrate_model(model, x, num_samples, batch_size=None, epochs=1):
+    """Calibrates model
+
+    Args:
+        model (keras.Model): the model to calibrate
+        x (tf.Dataset, np.array or generator): train input data
+        num_samples (int): total number of samples before declaring the calibration round finished.
+        batch_size (int, optional): the batch size. Defaults to None.
+        epochs (int, optional): the number of epochs. Defaults to 1.
+    """
+    if batch_size is None:
+        steps = num_samples
+    else:
+        assert batch_size > 0, "The batch size should be strictly positive."
+        steps = np.ceil(num_samples / batch_size)
+    set_calibrate(model, True)
+
+    progbar = Progbar(epochs)
+    for epoch in range(epochs):
+        progbar.update(epoch)
+        model.predict(x=x, steps=steps, batch_size=batch_size, verbose=0)
+    progbar.update(epochs, finalize=epochs)
+    set_calibrate(model, False)
+
+
 def evaluate_model(model,
                    x,
                    y=None,
@@ -148,6 +172,7 @@ def evaluate_akida_model(model, x, activation):
 
 
 def get_training_parser(batch_size,
+                        calibrate=False,
                         tune=False,
                         freeze_before=False,
                         global_batch_size=True,
@@ -159,6 +184,8 @@ def get_training_parser(batch_size,
 
     Args:
         batch_size (int): batch size default value
+        calibrate (bool, optional): either to add a calibrate action or not. Defaults to
+            False.
         tune (bool, optional): either to add a tune action or not. Defaults to
             False.
         freeze_before (bool, optional): either to add a "--freeze_before"
@@ -172,7 +199,8 @@ def get_training_parser(batch_size,
     Returns:
         argparse.ArgumentParser, argparse.ArgumentParser,
         argparse.ArgumentParser, argparse.ArgumentParser,
-        argparse._SubParsersAction: main parser and train, tune and eval actions
+        argparse.ArgumentParser,
+        argparse._SubParsersAction: main parser and train, calibrate, tune and eval actions
             subparsers and the subparser object.
     """
 
@@ -246,6 +274,17 @@ def get_training_parser(batch_size,
                                             help="Tune a Keras model")
 
     # Other subparsers
+    calibrate_parser = None
+    if calibrate:
+        calibrate_parser = subparsers.add_parser("calibrate",
+                                                 parents=[parent_parser],
+                                                 help="Calibrate a Keras model")
+        calibrate_parser.add_argument("-ns",
+                                      "--num_samples",
+                                      type=positive_int,
+                                      default=1024,
+                                      help="Number of samples to use for calibration")
+
     eval_parser = subparsers.add_parser("eval",
                                         help="Evaluate a model",
                                         parents=[global_parser])
@@ -255,7 +294,7 @@ def get_training_parser(batch_size,
                              action='store_true',
                              help="Converts to an Akida model and evaluate")
 
-    return parser, train_parser, tune_parser, eval_parser, subparsers
+    return parser, train_parser, tune_parser, eval_parser, calibrate_parser, subparsers
 
 
 def print_history_stats(history):
@@ -272,25 +311,3 @@ def print_history_stats(history):
     for key, values in clean_history.items():
         values = "\t".join(f"{f(values):.4f}" for f in stats)
         print(f"{key}\t{values}")
-
-
-class EarlyStoppingCalibration(Callback):
-    """A callback that limits the number of epochs to calibrate the model,
-        increasing the speed of the training.
-
-    Args:
-        trigger_epoch (int, optional): epoch at which to end the calibration.
-            Defaults to calibrate until the end of the training.
-
-    Notes:
-        If the :attr:`trigger_epoch` is set to 0, the model will never be calibrated
-    """
-
-    def __init__(self, trigger_epoch=-1):
-        self.trigger_epoch = trigger_epoch
-
-    def on_epoch_begin(self, epoch, logs=None):
-        calibrate = epoch < self.trigger_epoch or self.trigger_epoch < 0
-        set_calibrate(self.model, calibrate)
-        if logs is not None:
-            logs["calibrating"] = calibrate
